@@ -93,10 +93,10 @@ class SalesForceAPI:
 
     def ActiveFeatureLicenseMetric(self, fields=None):
         if not fields:
-            fields = [
-                'ActiveUserCount', 'AssignedUserCount', 'FeatureType',
-                'MetricsDate', 'TotalLicenseCount'
-            ]
+        fields = [
+            'ActiveUserCount', 'AssignedUserCount', 'FeatureType',
+            'MetricsDate', 'TotalLicenseCount'
+        ]
         fields = ',+'.join(fields)
         query = f'SELECT+{fields}+from+ActiveFeatureLicenseMetric'
         request_url = f'{self.url}/services/data/v53.0/query?q={query}'
@@ -118,5 +118,4 @@ class SalesForceAPI:
 
     def call_api(self, url):
         response = requests.get(url, headers=self.headers)
-        response = json.loads(response.text)
         return response
