@@ -37,7 +37,7 @@ class HttpListener:
             if request.method == 'GET':
                 self.respond_get()
             if request.method == 'POST':
-                self.respond_post(request)
+                self.respond_post()
 
         self.app.run(debug=True,
                      host='0.0.0.0',
